==> zio-aws-ec2_2.12-5.17.161.1-sources.jar: zio/aws/ec2/model/CreateTransitGatewayRouteTableResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayRouteTableResponse(
    transitGatewayRouteTable: Option[
      zio.aws.ec2.model.TransitGatewayRouteTable
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse = {
    import CreateTransitGatewayRouteTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
      .builder()
      .optionallyWith(
        transitGatewayRouteTable.map(value => value.buildAwsValue())
      )(_.transitGatewayRouteTable)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse
      .wrap(buildAwsValue())
}
object CreateTransitGatewayRouteTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse =
      zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse(
        transitGatewayRouteTable.map(value => value.asEditable)
      )
    def transitGatewayRouteTable
        : Option[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]
    def getTransitGatewayRouteTable: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayRouteTable",
      transitGatewayRouteTable
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly {
    override val transitGatewayRouteTable
        : Option[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly] = scala
      .Option(impl.transitGatewayRouteTable())
      .map(value => zio.aws.ec2.model.TransitGatewayRouteTable.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ): zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/CreateTransitGatewayRouteTableResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayRouteTableResponse(
    transitGatewayRouteTable: Optional[
      zio.aws.ec2.model.TransitGatewayRouteTable
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse = {
    import CreateTransitGatewayRouteTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
      .builder()
      .optionallyWith(
        transitGatewayRouteTable.map(value => value.buildAwsValue())
      )(_.transitGatewayRouteTable)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse
      .wrap(buildAwsValue())
}
object CreateTransitGatewayRouteTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse =
      zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse(
        transitGatewayRouteTable.map(value => value.asEditable)
      )
    def transitGatewayRouteTable
        : Optional[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]
    def getTransitGatewayRouteTable: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayRouteTable",
      transitGatewayRouteTable
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly {
    override val transitGatewayRouteTable
        : Optional[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayRouteTable())
        .map(value => zio.aws.ec2.model.TransitGatewayRouteTable.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayRouteTableResponse
  ): zio.aws.ec2.model.CreateTransitGatewayRouteTableResponse.ReadOnly =
    new Wrapper(impl)
}
